==> hoc-1.24.0.tgz: package/lib/withStateValue.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';

var withStateValue = function withStateValue(BaseComponent) {
  var _class, _temp;

  var displayName = BaseComponent.displayName;
  return _temp = _class =
  /*#__PURE__*/
  function (_Component) {
    _inheritsLoose(BaseComponentWithState, _Component);

    function BaseComponentWithState() {
      var _this;

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      _this = _Component.call.apply(_Component, [this].concat(args)) || this;
      _this.state = {
        value: _this.props.value
      };

      _this.onChange = function (e, valuesToPropagate) {
        var onChange = _this.props.onChange;
        var value = valuesToPropagate.value;

        _this.setState({
          value: value
        }, function () {
          return onChange(e, valuesToPropagate);
        });
      };

      return _this;
    }

    var _proto = BaseComponentWithState.prototype;

    _proto.render = function render() {
      var value = this.state.value;
      var onChange = this.onChange,
          props = this.props;
      return React.createElement(BaseComponent, Object.assign({}, props, {
        value: value,
        onChange: onChange
      }));
    };

    return BaseComponentWithState;
  }(Component), _class.displayName = "withStateValue(" + displayName + ")", _class.defaultProps = {
    onChange: function onChange() {}
  }, _temp;
};

export default withStateValue;

==> hoc-1.25.0.tgz: package/lib/withStateValue.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';

var withStateValue = function withStateValue(BaseComponent) {
  var _class, _temp;

  var displayName = BaseComponent.displayName;
  return _temp = _class = /*#__PURE__*/function (_Component) {
    _inheritsLoose(BaseComponentWithState, _Component);

    function BaseComponentWithState() {
      var _this;

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      _this = _Component.call.apply(_Component, [this].concat(args)) || this;
      _this.state = {
        value: _this.props.value
      };

      _this.onChange = function (e, valuesToPropagate) {
        var onChange = _this.props.onChange;
        var value = valuesToPropagate.value;

        _this.setState({
          value: value
        }, function () {
          return onChange(e, valuesToPropagate);
        });
      };

      return _this;
    }

    var _proto = BaseComponentWithState.prototype;

    _proto.render = function render() {
      var value = this.state.value;
      var onChange = this.onChange,
          props = this.props;
      return /*#__PURE__*/React.createElement(BaseComponent, Object.assign({}, props, {
        value: value,
        onChange: onChange
      }));
    };

    return BaseComponentWithState;
  }(Component), _class.displayName = "withStateValue(" + displayName + ")", _class.defaultProps = {
    onChange: function onChange() {}
  }, _temp;
};

export default withStateValue;
